@@ -45,31 +45,6 @@ string	my_strftime(const char *format, const struct tm *tm)
 	return string(buf.GetPtr());
 }
 
-string	ExpandEscape(const string &src)	// Expand &, <, >, " to HTML escapes
-{
-	string	dest;
-	size_t	len = src.size();
-	for (size_t i = 0; i < len; i++) {
-		switch(src[i]) {
-			case '&':
-				dest += "&amp;";
-				break;
-			case '\"':
-				dest += "&quot;";
-				break;
-			case '<':
-				dest += "&lt;";
-				break;
-			case '>':
-				dest += "&gt;";
-				break;
-			default:
-				dest += src[i];
-		}
-	}
-	return dest;
-}
-
 /*************************************************************************
 	Generate commonly used strings
 *************************************************************************/
