@@ -1,6 +1,6 @@
 /*
 	kcdmain.cc	Kriang's Change Directory
-	Copyright (c) 1996,1997,1998,1999,2000,2001 Kriang Lerdsuwanakij
+	Copyright (c) 1996,1997,1998,1999,2000,2001,2002 Kriang Lerdsuwanakij
 	email:		lerdsuwa@users.sourceforge.net
 
 	This program is free software; you can redistribute it and/or modify
@@ -71,7 +71,7 @@ void	PrintBanner()
 
 	cout << progName << ' ' << version
 	     << _(" - Kriang's Change Directory\n");
-	gtout(cout, _("(c) 1996-9,2000,2001 Kriang Lerdsuwanakij    "
+	gtout(cout, _("(c) 1996-9,2000-1,2002 Kriang Lerdsuwanakij    "
 		      "Release date: %$\n\n"))
 	     << my_strftime(_("%b %e, %Y"), &rel_time);
 
@@ -120,9 +120,7 @@ void	HelpInst()
 		  "                    (Works with ash)\n");
 	cout << _("     -ias DIR,      Same as -ia,-ic or -if but use the specified\n"
 		  "        -ics DIR,   directory\n"
-		  "        -ifs DIR\n");
-	cout << _("     -iau,-icu,-ifu Same as -ia,-ic or -if but use programs in user's\n"
-		  "                    directory\n\n");
+		  "        -ifs DIR\n\n");
 }
 
 void	Features()
@@ -161,6 +159,14 @@ void	Features()
 #endif
 	     << "\n";
 	
+	cout << _("     d_type speedup      : ")
+#ifdef	CLIB_HAVE_D_TYPE
+	     << _("Yes")
+#else
+	     << _("No")
+#endif
+	     << "\n";
+	
 	cout << '\n';
 }
 
@@ -311,24 +317,14 @@ void	mainReal(int argc, char *argv[])
 				return;
 			}
 			else if (strcmp(argv[argcCur], "-iau") == 0) {
-				if (argcLeft == 1)
-					cout << "alias kcd=\'. $HOME/kcd-bin/kcdscr\'\n";
-				else
-					throw ErrorGenericCommandLine(_("argument not allowed for `-iau\'"));
-				return;
+				throw ErrorGenericCommandLine(_("user-specific installation depreciated"));
 			}
 			else if (strcmp(argv[argcCur], "-icu") == 0) {
-				if (argcLeft == 1)
-					cout << "alias kcd \'source $home/kcd-bin/kcdscr\'\n";
-				else
-					throw ErrorGenericCommandLine(_("argument not allowed for `-icu\'"));
+				throw ErrorGenericCommandLine(_("user-specific installation depreciated"));
 				return;
 			}
 			else if (strcmp(argv[argcCur], "-ifu") == 0) {
-				if (argcLeft == 1)
-					cout << "kcd () { . $HOME/kcd-bin/kcdscr \"$@\" ; }\n";
-				else
-					throw ErrorGenericCommandLine(_("argument not allowed for `-ifu\'"));
+				throw ErrorGenericCommandLine(_("user-specific installation depreciated"));
 				return;
 			}
 			else if (strcmp(argv[argcCur], "-ias") == 0) {
