@@ -1180,8 +1180,12 @@ void	HyperDocument::ProcessHypertext(char *buffer, size_t length, WINDOW *pad)
 			i++;
 		}
 		else {
-			chtype	bufChar;	// Enough to cover 0..255
+			chtype	bufChar = '?';	// Enough to cover 0..255
+#ifdef USE_UTF8_MODE
+			bool	use_wide = false;
+			wchar_t	bufWChar;
 			int	charWidth = 1;
+#endif
 
 			switch(buffer[i]) {
 				case '\t':
@@ -1219,17 +1223,25 @@ void	HyperDocument::ProcessHypertext(char *buffer, size_t length, WINDOW *pad)
 						bufChar = static_cast<chtype>(bufChar_);
 					}
 					else {
-						bufChar = 0;
+							// For unknown escape
+						bufChar = '?';
+
 						for (size_t k = 0; entity_table[k].name; ++k) {
 							if (static_cast<size_t>(j-i) == entity_table[k].length
 							    && strncmp(buffer+i, entity_table[k].name, j-i) == 0) {
 								// FIXME: Handle wide/combining entity
-								bufChar = entity_table[k].code;
+#ifdef USE_UTF8_MODE
+								if (IsUTF8Mode()) {
+									use_wide = true;
+									bufWChar = entity_table[k].wc;
+									charWidth = wcwidth(bufWChar);
+								}
+								else
+#endif
+									bufChar = entity_table[k].code;
 								break;
 							}
 						}
-						//if (bufChar == 0)	// Unknown escape, print as a bullet
-						//	bufChar = ...get_entity(pad, EID_BULLET);
 
 					}
 					i = j;	/* i++ appears later... */
@@ -1238,21 +1250,16 @@ void	HyperDocument::ProcessHypertext(char *buffer, size_t length, WINDOW *pad)
 						// Assume no combining char
 #ifdef USE_UTF8_MODE
 					if (IsUTF8Mode()) {
-						wchar_t wc;
 						static mbstate_t state;
 						memset(&state, 0, sizeof(mbstate_t));
-						int ret = mbrtowc(&wc, buffer+i, length-i, &state);
+						int ret = mbrtowc(&bufWChar, buffer+i, length-i, &state);
 						if (ret <= 0)
 							throw ErrorBadSequence();
-								// Exceed ncurses limit
-						if (wc - (wc & 0xFFFF))
-							throw ErrorBadSequence();
-
-						bufChar = static_cast<chtype>(wc);
 
 						// FIXME: Check if printable logic correct?
-						if (iswprint(wc) || wc == ' ') {
-							charWidth = wcwidth(wc);
+						if (iswprint(bufWChar) || bufWChar == ' ') {
+							charWidth = wcwidth(bufWChar);
+							use_wide = true;
 							i += ret-1;
 						}
 						else {
@@ -1269,9 +1276,10 @@ void	HyperDocument::ProcessHypertext(char *buffer, size_t length, WINDOW *pad)
 					}
 			}
 
+#ifdef USE_UTF8_MODE
 			if (charWidth == 0) {
 				if (pad)
-					;	// FIXME: Use extended version of waddch
+					DrawWCharSub(pad, bufWChar);
 				i++;
 				continue;
 			}
@@ -1280,9 +1288,7 @@ void	HyperDocument::ProcessHypertext(char *buffer, size_t length, WINDOW *pad)
 					NextLine(pad);
 
 				if (pad)
-						// FIXME: Use extended version of waddch
-					for (int i = 0; i < charWidth; ++i)
-						waddch(pad, '?');
+					DrawWCharSub(pad, bufWChar);
 				else		// Keep track of char for wrap
 					for (int i = 0; i < charWidth; ++i)
 						lineBuffer[curColumn+i] = '*';
@@ -1299,6 +1305,7 @@ void	HyperDocument::ProcessHypertext(char *buffer, size_t length, WINDOW *pad)
 				i++;
 				continue;
 			}
+#endif
 
 				// Handle whitespaces
 				// or line too long outside <PRE> tag
@@ -1324,6 +1331,7 @@ void	HyperDocument::ProcessHypertext(char *buffer, size_t length, WINDOW *pad)
 					}
 
 						// Do wrap
+						// FIXME: Update for Unicode
 					else if (curColumn > scrColumn-1) {	
 						chtype	ch;
 						int	x = curColumn-1;
@@ -1469,8 +1477,11 @@ void	HyperDocument::ProcessHypertext(char *buffer, size_t length, WINDOW *pad)
 						// Not reach screen width yet
 					else {
 						// Display it
-						if (pad)
+						if (pad) {
+							// No need to deal with Unicode
+							// for space char.
 							waddch(pad, bufChar);
+						}
 						else
 							lineBuffer[curColumn] = bufChar;
 							
@@ -1529,7 +1540,12 @@ void	HyperDocument::ProcessHypertext(char *buffer, size_t length, WINDOW *pad)
 			else {			// Can be displayed directly
 			
 				if (pad) {	// Add char. to pad
-					waddch(pad, bufChar);
+#ifdef USE_UTF8_MODE
+					if (use_wide)
+						DrawWCharSub(pad, bufWChar);
+					else
+#endif
+						waddch(pad, bufChar);
 				}
 				else	// Keep track of char for wrap
 					lineBuffer[curColumn] = '*';
@@ -1831,6 +1847,7 @@ void	HyperDocument::DrawBegin(WINDOW *pad)
 	numNestA = 0;
 	numNestB = 0;
 	numNestI = 0;
+	numIndent = 0;
 
 	wmove(pad, 0, 0);
 }
@@ -1882,9 +1899,8 @@ void	HyperDocument::DrawClearBold(WINDOW *pad)
 void	HyperDocument::DrawCharSub(WINDOW *pad, chtype c)
 {
 	if (c == '\n') {
-		curRow++;
-		curColumn = 0;
-		wmove(pad, curRow, curColumn);
+						// Record column width
+		NextLine(pad);
 	}
 	else if (c == '\t' || c == '\r' || c == '\b' || c == '\0')
 		;
@@ -1911,9 +1927,8 @@ void	HyperDocument::DrawChar(WINDOW *pad, chtype c)
 void	HyperDocument::DrawWCharSub(WINDOW *pad, wchar_t wc)
 {
 	if (wc == '\n') {
-		curRow++;
-		curColumn = 0;
-		wmove(pad, curRow, curColumn);
+						// Record column width
+		NextLine(pad);
 	}
 	else if (wc == '\t' || wc == '\r' || wc == '\b' || wc == '\0')
 		;
