@@ -42,7 +42,7 @@ USING_NAMESPACE_STD
 // Decide whether mouse support should be activated
 // Some earlier versions of ncurses do not have mousemask(...)
 //
-#ifndef NCURSESAC_HAVE_MOUSEMASK
+#if !defined(NCURSESAC_HAVE_MOUSEMASK) || !defined(NCURSESAC_ENABLE_MOUSE)
 # undef NCURSES_MOUSE_VERSION
 #endif
 
