@@ -90,6 +90,7 @@ size_t	GetStringWidth(const string &s);
 						// FIXME: Use wstring
 size_t	GetWStringWidth(const k_wstring &s);
 size_t	GetWStringWidth(const k_wstring &s, size_t n);
-size_t	GetWStringWidthFirstCharAtPos(const k_wstring &s, size_t pos);
+size_t	GetWStringLastCharAtPos(const k_wstring &s, size_t pos);
+size_t	GetWStringWidthLastCharAtPos(const k_wstring &s, size_t pos);
 
 #endif	/* __K_STRMISC_H */
